--- pyobjc_setup.py.orig 2019-10-16 20:40:22.000000000 +1100
+++ pyobjc_setup.py 2019-10-24 20:40:00.000000000 +1100
return '.'.join(v.split('.')[:2])
- cflags = get_config_var('CFLAGS')
- cflags = shlex.split(cflags)
- for i, val in enumerate(cflags):
+ env_cflags = os.environ.get('CFLAGS', '')
+ config_cflags = get_config_var('CFLAGS')
+ for cflags_str in [env_cflags, config_cflags]:
+ cflags = shlex.split(cflags_str)
+ for i, val in enumerate(cflags):
+ elif val.find('-isysroot') == 0:
+ sdk = val[len('-isysroot'):]
sdk = os.path.basename(sdk)
assert sdk.startswith('MacOSX')
assert sdk.endswith('.sdk')
+ if sdk == 'MacOSX.sdk':
class pyobjc_install_lib (install_lib.install_lib):
def get_exclusions(self):
if 'clang' in get_config_var('CC'):
cflags.append('-Wno-deprecated-declarations')
- CFLAGS = get_config_var('CFLAGS')
- if '-isysroot' not in CFLAGS: # and os.path.exists('/usr/include/stdio.h'):
- # We're likely on a system with de Xcode Command Line Tools.
- # Explicitly use the most recent problems to avoid compile problems.
+ if not sdk: # and os.path.exists('/usr/include/stdio.h'):
+ # We're likely on a system with the Xcode Command Line Tools.
+ # Explicitly use the most recent SDK to avoid compile problems.
data = os.popen('/usr/bin/xcrun -sdk macosx --show-sdk-path').read()